<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Clenix_Core;

use ClenixTheme;
use ClenixTheme_Helper;
use \WP_Query;

$thumb_size = 'clenix-size7';

if ( get_query_var('paged') ) {
	$paged = get_query_var('paged');
}
else if ( get_query_var('page') ) {
	$paged = get_query_var('page');
}
else {
	$paged = 1;
}

$number_of_post = $data['itemnumber'];
$post_sorting = $data['orderby'];
$post_ordering = $data['post_ordering'];
$title_count = $data['title_count'];
$excerpt_count = $data['excerpt_count'];	
$cat_single_grid = $data['cat_single'];
$args = array(
	'post_type' => 'clenix_portfolio',
	'post_status' => 'publish',
	'orderby' => $post_sorting,
	'order' => $post_ordering,
	'posts_per_page' => $number_of_post,
	'paged'          => $paged,
);

if ( $cat_single_grid != 0 ) {
	$args['tax_query'] = array (
		array (
			'taxonomy' => 'clenix_portfolio_category',
			'field'    => 'ID',
			'terms'    => $cat_single_grid,
		)
	);
}

$title_css ='';
$title_size = $data['title_size'];

if ( $title_size != '' ) {
   $title_size       = (int) $title_size;
   $title_css  .= "font-size: {$title_size}px;";
}

$query = new WP_Query( $args );
$slider_nav_class = $data['slider_nav'] == 'yes' ? 'slider-nav-enabled' : '';
$slider_dot_class = $data['slider_dots'] == 'yes' ? ' slider-dot-enabled' : '';

?>
<div class="portfolio-slider-default rt-owl-nav-3 owl-wrap portfolio-slider-<?php echo esc_attr( $data['layout'] );?> <?php echo esc_attr( $slider_nav_class ); ?><?php echo esc_attr( $slider_dot_class ); ?>">
	<div class="owl-theme owl-carousel rt-owl-carousel" data-carousel-options="<?php echo esc_attr( $data['owl_data'] );?>">	
		<?php
			if ( $query->have_posts() ) {
				while ( $query->have_posts() ) {
				$query->the_post();			
				$excerpt = wp_trim_words( get_the_excerpt(), $excerpt_count, '' );
				$portfolio_title = wp_trim_words( get_the_title(), $title_count, '' );
		?>
		<div class="rtin-item">
			<div class="rtin-figure">
				<a href="<?php the_permalink(); ?>">
					<?php
						if ( has_post_thumbnail() ){
							the_post_thumbnail( $thumb_size, ['class' => 'img-fluid mb-10 width-100'] );
						} else {
							if ( !empty( ClenixTheme::$options['no_preview_image']['id'] ) ) {
								echo wp_get_attachment_image( ClenixTheme::$options['no_preview_image']['id'], $thumb_size );
							} else {
								echo '<img class="wp-post-image" src="' . ClenixTheme_Helper::get_img( 'noimage_620X672.jpg' ) . '" alt="'.get_the_title().'">';
							}
						}
					?>
				</a>
            </div>
			<div class="rtin-content-wrap">
                <svg width="588" height="57" viewBox="0 0 588 57" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M0 2.24385C2.60526 0.320214 6.78302 -0.383239 9.91974 1.04538C14.3879 3.08192 15.207 8.73777 11.4374 11.5234C16.1193 9.87328 22.2448 11.5863 24.5843 15.1969C25.5404 9.37609 36.1888 7.09421 42.013 10.72C47.8372 14.3459 48.7111 21.3804 45.9716 26.8343C50.8698 25.6771 56.6502 27.9525 58.45 31.7433C59.491 29.0554 60.617 26.2546 63.1072 24.2528C65.5974 22.251 69.9039 21.3608 72.7338 23.0587C73.0269 16.7015 83.8699 13.1126 90.8775 16.2152C97.8852 19.3178 100.436 26.7019 98.655 32.9049C105.413 32.4272 112.363 35.3583 115.637 40.0675C119.338 37.0062 125.886 36.4482 130.324 38.8147C129.398 35.3865 133.466 32.0494 137.857 31.6304C142.249 31.2114 146.536 32.9874 149.906 35.2562C152.415 29.4484 161.302 25.9376 168.663 27.8439C176.024 29.7502 180.58 36.7434 178.276 42.6056C183.727 39.3228 192.001 39.4053 197.348 42.7966C196.288 37.9984 202.063 33.6213 208.125 32.8245C214.188 32.0277 220.272 33.7842 226.02 35.5102C221.138 29.6677 223.686 20.7703 231.269 17.1662C238.852 13.5642 249.955 15.9786 254.155 22.1446C265.907 13.5838 279.048 4.5431 294.984 3.92432C297.332 3.83314 299.685 3.95038 302 4.25V56.795H0V2.24385Z" fill="white"/>
                    <path d="M595 2.24385C592.395 0.320214 588.217 -0.383239 585.08 1.04538C580.612 3.08192 579.793 8.73777 583.563 11.5234C578.881 9.87328 572.755 11.5863 570.416 15.1969C569.46 9.37609 558.811 7.09421 552.987 10.72C547.163 14.3459 546.289 21.3804 549.028 26.8343C544.13 25.6771 538.35 27.9525 536.55 31.7433C535.509 29.0554 534.383 26.2546 531.893 24.2528C529.403 22.251 525.096 21.3608 522.266 23.0587C521.973 16.7015 511.13 13.1126 504.122 16.2152C497.115 19.3178 494.564 26.7019 496.345 32.9049C489.587 32.4272 482.637 35.3583 479.363 40.0675C475.662 37.0062 469.114 36.4482 464.676 38.8147C465.602 35.3865 461.534 32.0494 457.143 31.6304C452.751 31.2114 448.464 32.9874 445.094 35.2562C442.585 29.4484 433.698 25.9376 426.337 27.8439C418.976 29.7502 414.42 36.7434 416.724 42.6056C411.273 39.3228 402.999 39.4053 397.652 42.7966C398.712 37.9984 392.937 33.6213 386.875 32.8245C380.812 32.0277 374.728 33.7842 368.98 35.5102C373.862 29.6677 371.314 20.7703 363.731 17.1662C356.148 13.5642 345.045 15.9786 340.845 22.1446C329.093 13.5838 315.952 4.5431 300.016 3.92432C297.668 3.83314 295.315 3.95038 293 4.25V56.795H595V2.24385Z" fill="white"/>
                </svg>
                <div class="title-wrap">
                    <div class="rtin-content">
                        <h3 style="<?php echo wp_kses_post( $title_css ); ?>"><a href="<?php the_permalink(); ?>"><?php echo esc_html( $portfolio_title );?></a></h3>
                        <?php if ( $data['excerpt_display'] == 'yes' ) { ?>
                        <p><?php echo wp_kses_post( $excerpt );?></p>
                        <?php } ?>
                        <?php if ( $data['cat_display'] == 'yes' ) { ?>
                        <div class="rtin-cat"><?php
                            $i = 1;
                            $term_lists = get_the_terms( get_the_ID(), 'clenix_portfolio_category' );
                            foreach ( $term_lists as $term_list ){
                            $link = get_term_link( $term_list->term_id, 'clenix_portfolio_category' ); ?><?php if ( $i > 1 ){ echo esc_html( ', ' ); } ?><a href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $term_list->name ); ?></a><?php $i++; } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <?php if ( $data['read_display'] == 'yes' ) { ?>
                    <div class="rtin-read"><a href="<?php the_permalink(); ?>">
                        <svg width="23" height="17" viewBox="0 0 23 17" fill="none" xmlns="http://www.w3.org/2000/svg">
                            <path d="M1.5 8.5H21.5M21.5 8.5L14.5 1.5M21.5 8.5L14.5 15.5" stroke="black" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
                        </svg></a>
                    </div>
                    <?php } ?>
                </div>
            </div>
        </div>
		<?php } ?>
	<?php } ?>
	<?php wp_reset_postdata();?>
	</div>
</div>