<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Clenix_Core;

use ClenixTheme;
use ClenixTheme_Helper;
use \WP_Query;

$prefix      = CLENIX_CORE_THEME_PREFIX;
$thumb_size  = 'clenix-size4';

$args = array(
	'post_type'      => 'clenix_team',
	'posts_per_page' => $data['number'],
	'orderby'        => $data['orderby'],
);

if ( !empty( $data['cat'] ) ) {
	$args['tax_query'] = array(
		array(
			'taxonomy' => 'clenix_team_category',
			'field' => 'term_id',
			'terms' => $data['cat'],
		)
	);
}

switch ( $data['orderby'] ) {
	case 'title':
	case 'menu_order':
	$args['order'] = 'ASC';
	break;
}

$query = new WP_Query( $args );
$slider_nav_class = $data['slider_nav'] == 'yes' ? 'slider-nav-enabled' : '';
$slider_dot_class = $data['slider_dots'] == 'yes' ? ' slider-dot-enabled' : '';
?>
<div class="team-default team-multi-layout-8 rt-owl-nav-2 owl-wrap team-slider-<?php echo esc_attr( $data['style'] );?> <?php echo esc_attr( $slider_nav_class ); ?><?php echo esc_attr( $slider_dot_class ); ?>">
	<div class="owl-theme owl-carousel rt-owl-carousel" data-carousel-options="<?php echo esc_attr( $data['owl_data'] );?>">
		<?php if ( $query->have_posts() ) :?>
			<?php while ( $query->have_posts() ) : $query->the_post();?>
				<?php
				$id            	= get_the_id();
				$designation   	= get_post_meta( $id, 'clenix_team_designation', true );
				$socials       	= get_post_meta( $id, 'clenix_team_socials', true );
				$social_fields 	= ClenixTheme_Helper::team_socials();
				?>
				<div class="rtin-item">
					<div class="rtin-content-wrap">
                        <h3 class="rtin-title"><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
						<?php if ( $designation && $data['designation_display']  == 'yes' ): ?>
                            <div class="rtin-designation"><?php echo esc_html( $designation );?></div>
						<?php endif; ?>
						<figure>
							<a href="<?php the_permalink();?>">
								<?php
								if ( has_post_thumbnail() ){
									the_post_thumbnail( $thumb_size );
								}
								else {
									if ( !empty( ClenixTheme::$options['no_preview_image']['id'] ) ) {
										echo wp_get_attachment_image( ClenixTheme::$options['no_preview_image']['id'], $thumb_size );
									}
									else {
										echo '<img class="wp-post-image" src="' . ClenixTheme_Helper::get_img( 'noimage_400X400.jpg' ) . '" alt="'.get_the_title().'">';
									}
								}
								?>
							</a>
						</figure>
						<div class="mask-wrap">
                            <svg width="211" height="54" viewBox="0 0 211 54" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M-1.66669 1.55161C0.16217 0.201238 3.09488 -0.292576 5.29683 0.710294C8.4334 2.13992 9.00841 6.11025 6.36223 8.06569C9.64879 6.90736 13.9488 8.10989 15.5912 10.6445C16.2623 6.55834 23.7374 4.95649 27.8259 7.50177C31.9144 10.047 32.5278 14.9852 30.6048 18.8138C34.0432 18.0014 38.101 19.5987 39.3644 22.2598C40.0952 20.373 40.8856 18.4068 42.6337 17.0016C44.3818 15.5964 47.4049 14.9715 49.3915 16.1633C49.5972 11.7007 57.2088 9.18135 62.1281 11.3593C67.0474 13.5373 68.8378 18.7208 67.5878 23.0752C72.3321 22.7399 77.2109 24.7975 79.509 28.1033C82.1071 25.9543 86.7033 25.5626 89.8188 27.2239C89.1688 24.8173 92.0246 22.4747 95.1073 22.1806C98.19 21.8864 101.2 23.1331 103.565 24.7258C105.327 20.6488 111.565 18.1843 116.732 19.5225C121.9 20.8607 125.098 25.7699 123.481 29.885C127.308 27.5805 133.115 27.6384 136.869 30.0191C136.125 26.6508 140.179 23.5782 144.435 23.0188C148.69 22.4595 152.962 23.6925 156.996 24.9042C153.569 20.8028 155.358 14.5569 160.681 12.0269C166.004 9.49837 173.798 11.1932 176.746 15.5217C184.997 9.51208 194.222 3.16565 205.408 2.73128C207.056 2.66726 208.708 2.74957 210.333 2.95989V60.9054H-1.66669V1.55161Z" fill="#EEF5FD"/>
                            </svg>
							<div class="rtin-content <?php if ( empty( $socials ) ||( $data['social_display']  == NULL ) || $data['social_display']  == '0' ) { ?>no-social<?php } ?>">
								<?php if ( !empty( $socials ) && $data['social_display']  == 'yes' ) { ?>
								<ul class="rtin-social">
									<?php foreach ( $socials as $key => $social ): ?>
										<?php if ( !empty( $social ) ): ?>
											<li><a target="_blank" href="<?php echo esc_url( $social );?>"><i class="fab <?php echo esc_attr( $social_fields[$key]['icon'] );?>" aria-hidden="true"></i></a></li>
										<?php endif; ?>
									<?php endforeach; ?>
								</ul>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>
			<?php endwhile;?>
		<?php endif;?>
		<?php wp_reset_postdata();?>
	</div>
</div>