<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */
namespace radiustheme\Clenix_Core;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Base;
if ( ! defined( 'ABSPATH' ) ) exit;

class Info_Box extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'RT Info Box', 'clenix-core' );
		$this->rt_base = 'rt-info-box';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){
		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'General', 'clenix-core' ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'style',
				'label'   => esc_html__( 'Style', 'clenix-core' ),
				'options' => array(
					'style1' => esc_html__( 'Style 1', 'clenix-core' ),
					'style2' => esc_html__( 'Style 2', 'clenix-core' ),
					'style3' => esc_html__( 'Style 3', 'clenix-core' ),
					'style4' => esc_html__( 'Style 4', 'clenix-core' ),
					'style5' => esc_html__( 'Style 5', 'clenix-core' ),
					'style6' => esc_html__( 'Style 6', 'clenix-core' ),
					'style7' => esc_html__( 'Style 7', 'clenix-core' ),
					'style8' => esc_html__( 'Style 8', 'clenix-core' ),
					'style9' => esc_html__( 'Style 9', 'clenix-core' ),
					'style10' => esc_html__( 'Style 10', 'clenix-core' ),
					'style11' => esc_html__( 'Style 11', 'clenix-core' ),
					'style12' => esc_html__( 'Style 12', 'clenix-core' ),
					'style13' => esc_html__( 'Style 13', 'clenix-core' ),
					'style14' => esc_html__( 'Style 14', 'clenix-core' ),
				),
				'default' => 'style1',
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'backg_color',
				'label'   => esc_html__( 'Theme', 'clenix-core' ),
				'options' => array(
					'light' => esc_html__( 'Light Background', 'clenix-core' ),
					'dark' => esc_html__( 'Dark Background' , 'clenix-core' ),
				),
				'default' => 'light',
				'condition'   => array( 'style' => array( 'style3', 'style4', 'style6', 'style7', 'style8' ) ),
			),		
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'box_back_color',
				'label'   => esc_html__( 'Box Background Color', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'backg_color' => array( 'dark' ), 'style' => array( 'style3', 'style4', 'style6', 'style7', 'style8' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-style4 .rtin-item' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style3 .rtin-item' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style6 .rtin-item' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style7 .rtin-item' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style8 .rtin-item' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'box_backhov_color',
				'label'   => esc_html__( 'Box background hover color', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'backg_color' => array( 'dark' ), 'style' => array( 'style6', 'style7', 'style8' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-style6 .rtin-item:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style7 .rtin-item:hover' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .info-style8 .rtin-item:hover' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'title_align',
				'label'   => esc_html__( 'Content Align', 'clenix-core' ),
				'options' => array(
					'left' => esc_html__( 'Align Left' , 'clenix-core' ),
					'center' => esc_html__( 'Align Center', 'clenix-core' ),
					'right' => esc_html__( 'Align right', 'clenix-core' ),
				),
				'default' => 'center',
				'condition'   => array( 'style!' => array( 'style8' ) ),
			),			
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'shadow',
				'label'   => esc_html__( 'Shadow', 'clenix-core' ),
				'options' => array(
					'shadow-show' => esc_html__( 'Show', 'clenix-core' ),
					'shadow-hide' => esc_html__( 'Hide' , 'clenix-core' ),
				),
				'default' => 'shadow-show',
				'condition'   => array( 'style' => array( 'style1' ) ),
			),	
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'layout_one_image',
				'label'   => esc_html__( 'Image', 'clenix-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style14' ) ),
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'icontype',
				'label'   => esc_html__( 'Icon Type', 'clenix-core' ),
				'options' => array(
					'icon'  => esc_html__( 'Icon', 'clenix-core' ),
					'image' => esc_html__( 'Custom Image', 'clenix-core' ),
				),
				'default' => 'icon',
			),
			array(
				'type'    => Controls_Manager::ICON,
				'id'      => 'icon',
				'label'   => esc_html__( 'Icon', 'clenix-core' ),
				'default' => 'fa fa-check',
				'condition'   => array( 'icontype' => array( 'icon' ) ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'image',
				'label'   => esc_html__( 'Image', 'clenix-core' ),
				'condition'   => array( 'icontype' => array( 'image' ) ),
				'description' => esc_html__( 'Recommended jpg, png, svg image', 'clenix-core' ),
			),
			array(
				'type'    => Controls_Manager::MEDIA,
				'id'      => 'icon_back_image',
				'label'   => esc_html__( 'Icon Background Image', 'clenix-core' ),
				'description' => esc_html__( 'Recommended image size is 120x120 px', 'clenix-core' ),
				'condition'   => array( 'style' => array( 'style2' ) ),
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'title',
				'label'   => esc_html__( 'Title', 'clenix-core' ),
				'default' => esc_html__( 'Digital Solutions', 'clenix-core' ),
			),
			array(
				'type'    => Controls_Manager::WYSIWYG,
				'id'      => 'content',
				'label'   => esc_html__( 'Content', 'clenix-core' ),
				'default' => esc_html__( 'Grursus mal suada faci lisis is an Lorem is ipsum dolarorit more as ametion that the dummy text elit.', 'clenix-core' ),
				'condition'   => array( 'style!' => array( 'style8' ) ),
			),
			array(
				'type'  => Controls_Manager::URL,
				'id'    => 'url',
				'label' => esc_html__( 'Link (Optional)', 'clenix-core' ),
				'placeholder' => 'https://your-link.com',
			),
			array(
				'type'    => Controls_Manager::TEXT,
				'id'      => 'buttontext',
				'label'   => esc_html__( 'Button Text', 'clenix-core' ),
				'default' => esc_html__( 'Read More', 'clenix-core' ),
				'condition'   => array( 'style' => array( 'style1', 'style2', 'style3', 'style5', 'style11', 'style13', 'style14' ) ),
			),
			array(
				'mode' => 'section_end',
			),

			// Title Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_style',
				'label'   => esc_html__( 'Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'title_typo',
				'label'   => esc_html__( 'Title Typo', 'clenix-core' ),
				'selector' => '{{WRAPPER}} .info-box .rtin-item-title',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Title Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-item-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .info-box .rtin-item-title a' => 'color: {{VALUE}}',
				),
			),
			array(
				'label'      => __( 'Title Space', 'clenix-core' ),
				'id'      => 'title_space',
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 50,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .info-box .rtin-item .rtin-item-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'content_typo',
				'label'   => esc_html__( 'Content Typo', 'clenix-core' ),
				'selector' => '{{WRAPPER}} .info-box .rtin-text',
			),
			array(
				'label'      => __( 'Content Space', 'clenix-core' ),
				'id'      => 'content_space',
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 50,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .info-box .rtin-text p' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'content_color',
				'label'   => esc_html__( 'Content Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-text' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),

			// Icon Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_icon_style',
				'label'   => esc_html__( 'Icon Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'icon_size',
				'label'   => esc_html__( 'Icon Size', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'icontype' => array( 'icon' ), 'style' => array( 'style1', 'style2', 'style4', 'style5', 'style9', 'style13', 'style14' ) ),
			),
			array(
				'type'    => Controls_Manager::NUMBER,
				'id'      => 'icon_image_size',
				'label'   => esc_html__( 'Icon Size', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'icontype' => array( 'image' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-item .image-svg img' => 'width: {{VALUE}}px',
					'{{WRAPPER}} .info-box .rtin-item .image-svg svg' => 'width: {{VALUE}}px',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'icon_bag_color',
				'label'   => esc_html__( 'Icon Background Color', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'style' => array( 'style1','style3','style6', 'style9', 'style10', 'style12', 'style14' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-style1 .rtin-item .rtin-icon' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style3 .rtin-item span' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style6 .rtin-item .rtin-media > span' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style14 .rtin-item .rtin-icon' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style9 .rtin-item .rtin-media span > span' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style10 .rtin-item .rtin-media > span' => 'background: {{VALUE}}',
					'{{WRAPPER}} .info-style12 .rtin-item .rtin-media > span' => 'background: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'icon_color',
				'label'   => esc_html__( 'Icon Color', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'icontype' => array( 'icon' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-icon .rtin-media span i' => 'color: {{VALUE}} !important',
					'{{WRAPPER}} .info-style8 .rtin-item .rtin-content h3:after' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'svg_color',
				'label'   => esc_html__( 'Svg Color', 'clenix-core' ),
				'default' => '',
				'condition'   => array( 'icontype' => array( 'image' ) ),
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-item .image-svg svg' => 'fill: {{VALUE}} !important',
					'{{WRAPPER}} .info-box .rtin-item .image-svg svg path' => 'fill: {{VALUE}} !important',
				),
			),
			array(
				'label'      => __( 'Width', 'clenix-core' ),
				'id'      => 'icon_width',
				'mode'              => 'responsive',
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .info-style9 .rtin-item .rtin-media span > span' => 'width: {{SIZE}}{{UNIT}}; display: flex; justify-content: center; align-items: center;',
					'{{WRAPPER}} .info-style10 .rtin-item .rtin-media > span' => 'width: {{SIZE}}{{UNIT}}; display: flex; justify-content: center; align-items: center;',
					'{{WRAPPER}} .info-style12 .rtin-item .rtin-media > span' => 'width: {{SIZE}}{{UNIT}}; display: flex; justify-content: center; align-items: center;',
				],
				'condition'   => array( 'icontype' => array( 'icon' ), 'style' => array( 'style9', 'style10', 'style12' ) ),
			),
			array(
				'label'      => __( 'Height', 'clenix-core' ),
				'id'      => 'icon_height',
				'mode'              => 'responsive',
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .info-style9 .rtin-item .rtin-media span > span' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .info-style10 .rtin-item .rtin-media > span' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .info-style12 .rtin-item .rtin-media > span' => 'height: {{SIZE}}{{UNIT}};',
				],
				'condition'   => array( 'icontype' => array( 'icon' ), 'style' => array( 'style9', 'style10', 'style12' ) ),
			),
			array (
				'label'              => __( 'Radius', 'clenix-core' ),
				'id'                 => 'radius',
				'mode'              => 'responsive',
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => [ 'px', '%' ],
				'selectors'          => [
					'{{WRAPPER}} .info-style9 .rtin-item .rtin-media span > span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
					'{{WRAPPER}} .info-style10 .rtin-item .rtin-media > span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
					'{{WRAPPER}} .info-style12 .rtin-item .rtin-media > span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
				'condition'   => array( 'icontype' => array( 'icon' ), 'style' => array( 'style9', 'style10', 'style12' ) ),
			),

			array(
				'mode' => 'section_end',
			),

			// Button Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_button_style',
				'label'   => esc_html__( 'Button Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_color',
				'label'   => esc_html__( 'Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-button a' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_hover_color',
				'label'   => esc_html__( 'Hover Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-button a:hover' => 'color: {{VALUE}} !important',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_bg_color',
				'label'   => esc_html__( 'Background Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-button a' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'button_bg_hover_color',
				'label'   => esc_html__( 'Background Hover Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rtin-button a:before' => 'background-color: {{VALUE}}',
				),
			),
			array(
				'label'      => __( 'Button Space', 'clenix-core' ),
				'id'      => 'button_space',
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 50,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .info-box .rtin-button' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			),
			array (
				'label'              => __( 'Padding', 'clenix-core' ),
				'id'                 => 'button_padding',
				'mode'               => 'responsive',
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => [ 'px', '%' ],
				'selectors'          => [
					'{{WRAPPER}} .info-box .rtin-button a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			),
			array (
				'label'              => __( 'Radius', 'clenix-core' ),
				'id'                 => 'button_radius',
				'mode'               => 'responsive',
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => [ 'px', '%' ],
				'selectors'          => [
					'{{WRAPPER}} .info-box .rtin-button a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			),
			array(
				'mode' => 'section_end',
			),

			// Box Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_box_style',
				'label'   => esc_html__( 'Box Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
				'condition'   => array( 'style' => array( 'style5', 'style13' ) ),
			),
			array(
				'type'        => Controls_Manager::SWITCHER,
				'id'          => 'shape_display',
				'label'       => esc_html__( 'Shape Display', 'clenix-core' ),
				'label_on'    => esc_html__( 'On', 'clenix-core' ),
				'label_off'   => esc_html__( 'Off', 'clenix-core' ),
				'default'     => false,
				'description' => esc_html__( 'Show or Hide Content. Default: off', 'clenix-core' ),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'shape_color',
				'label'   => esc_html__( 'Shape Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box .rt-shape path' => 'fill: {{VALUE}}',
				),
				'condition'   => array( 'shape_display' => array( 'yes' ) ),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'box_bg_color',
				'label'   => esc_html__( 'Background Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .info-box-style .rtin-item' => 'background-color: {{VALUE}}',
				),
			),
			array (
				'label'              => __( 'Padding', 'clenix-core' ),
				'id'                 => 'box_padding',
				'mode'               => 'responsive',
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => [ 'px', '%' ],
				'selectors'          => [
					'{{WRAPPER}} .info-box-style .rtin-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			),
			array (
				'label'              => __( 'Radius', 'clenix-core' ),
				'id'                 => 'box_radius',
				'mode'               => 'responsive',
				'type'               => Controls_Manager::DIMENSIONS,
				'size_units'         => [ 'px', '%' ],
				'selectors'          => [
					'{{WRAPPER}} .info-box-style .rtin-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			),
			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		switch ( $data['style'] ) {
			case 'style14':
			$template = 'info-box-14';
			break;
			case 'style13':
			$template = 'info-box-13';
			break;
			case 'style12':
			$template = 'info-box-12';
			break;
			case 'style11':
			$template = 'info-box-11';
			break;
			case 'style10':
			$template = 'info-box-10';
			break;
			case 'style9':
			$template = 'info-box-9';
			break;
			case 'style8':
			$template = 'info-box-8';
			break;
			case 'style7':
			$template = 'info-box-7';
			break;
			case 'style6':
			$template = 'info-box-6';
			break;
			case 'style5':
			$template = 'info-box-5';
			break;
			case 'style4':
			$template = 'info-box-4';
			break;
			case 'style3':
			$template = 'info-box-3';
			break;
			case 'style2':
			$template = 'info-box-2';
			break;
			default:
			$template = 'info-box-1';
			break;
		}

		return $this->rt_template( $template, $data );
	}
}