<?php
/**
 * @author  RadiusTheme
 * @since   1.0
 * @version 1.0
 */

namespace radiustheme\Clenix_Core;
use Elementor\Group_Control_Typography;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit;

class RT_Marquee extends Custom_Widget_Base {

	public function __construct( $data = [], $args = null ){
		$this->rt_name = esc_html__( 'RT Marquee', 'clenix-core' );
		$this->rt_base = 'rt-marquee';
		parent::__construct( $data, $args );
	}

	public function rt_fields(){

		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'title', [
				'type'  => Controls_Manager::TEXT,
				'label' => esc_html__( 'Title', 'clenix-core' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'url', [
				'type'        => Controls_Manager::URL,
				'label' => esc_html__( 'URL(optional)', 'clenix-core' ),
				'label_block' => true,
			]
		);

		$fields = array(
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_general',
				'label'   => esc_html__( 'RT Marquee', 'clenix-core' ),
			),

			array(
				'type'    => Controls_Manager::REPEATER,
				'id'      => 'items',
				'label'   => esc_html__( 'Add as many logos as you want', 'clenix-core' ),
				'fields' => $repeater->get_controls(),'title_field' => '{{{ title }}}',
				'default'     => [
					[ 'title' => 'Modern Cleaning Equipments', ],
					[ 'title' => '24/7 Customer Service', ],
					[ 'title' => 'Need an appointment for Cleaning Service', ],
					[ 'title' => '100% Satisfied Customer', ],
					[ 'title' => 'Cleaning Apartments', ],
				],
			),

			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'marquee_direction',
				'label'   => esc_html__( 'Marquee Direction', 'clenix-core' ),
				'default'   => 'marquee-left',
				'options'   => [
					'marquee-left'  => __( 'Left Direction', 'clenix-core' ),
					'marquee-right' => __( 'Right Direction', 'clenix-core' ),
				],
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'heading_tag',
				'label'   => esc_html__( 'Title Tag', 'clenix-core' ),
				'default' => 'h3',
				'options' => [
					'h1' => esc_html__( 'H1', 'clenix-core' ),
					'h2' => esc_html__( 'H2', 'clenix-core' ),
					'h3' => esc_html__( 'H3', 'clenix-core' ),
					'h4' => esc_html__( 'H4', 'clenix-core' ),
					'h5' => esc_html__( 'H5', 'clenix-core' ),
					'h6' => esc_html__( 'H6', 'clenix-core' ),
				],
			),
			array(
				'mode' => 'section_end',
			),

			// Title Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_style',
				'label'   => esc_html__( 'Title Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array (
				'mode'    => 'group',
				'type'    => Group_Control_Typography::get_type(),
				'name'    => 'title_typo',
				'label'   => esc_html__( 'Typo', 'clenix-core' ),
				'selector' => '{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .entry-title',
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_color',
				'label'   => esc_html__( 'Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .entry-title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .entry-title a' => 'color: {{VALUE}}',
				),
			),
			array(
				'type'    => Controls_Manager::COLOR,
				'id'      => 'title_hover_color',
				'label'   => esc_html__( 'Hover Color', 'clenix-core' ),
				'default' => '',
				'selectors' => array(
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .entry-title a:hover' => 'color: {{VALUE}}',
				),
			),
			array(
				'mode' => 'section_end',
			),

			// Icon Style
			array(
				'mode'    => 'section_start',
				'id'      => 'sec_icon_style',
				'label'   => esc_html__( 'Icon Style', 'clenix-core' ),
				'tab'     => Controls_Manager::TAB_STYLE,
			),
			array(
				'type'    => Controls_Manager::SELECT2,
				'id'      => 'icon_type',
				'label' => __('Icon Type', 'clenix-core'),
				'default' => 'icon',
				'options' => [
					'icon' => __('Icon', 'clenix-core'),
					'image' => __('Image', 'clenix-core'),
					'none' => __('None', 'clenix-core'),
				],
			),
			array(
				'id'      => 'bgicon',
				'label' => __('Choose Icon', 'clenix-core'),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => [
					'icon_type' => ['icon'],
				],
			),
			array(
				'id'      => 'image',
				'label' => __('Choose Image', 'clenix-core'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'icon_type' => ['image'],
				],
			),
			array(
				'id'      => 'icon_typo',
				'type'    => Controls_Manager::SLIDER,
				'label'   => esc_html__( 'Icon Size', 'toyup-core' ),
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder svg' => 'width: {{SIZE}}{{UNIT}}; height: 100%;',
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder img' => 'width: {{SIZE}}{{UNIT}};',
				],
			),
			array(
				'id'      => 'icon_fill_color',
				'type'      => Controls_Manager::COLOR,
				'label'     => esc_html__( 'Icon Color', 'fasheno-core' ),
				'selectors' => [
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder' => 'color: {{VALUE}}',
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder path' => 'fill: {{VALUE}}',
				],
			),
			array(
				'id'        =>'icon_gap',
				'type'    => Controls_Manager::SLIDER,
				'mode'    => 'responsive',
				'label'   => esc_html__( 'Icon Gap', 'toyup-core' ),
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 400,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .rt-marquee-slider .rt-marquee-item .icon-holder' => 'width: {{SIZE}}{{UNIT}};',
				],
			),

			array(
				'mode' => 'section_end',
			),
		);
		return $fields;
	}

	protected function render() {
		$data = $this->get_settings();

		$template = 'rt-marquee';

		return $this->rt_template( $template, $data );
	}
}